==> everycomp-1.20-2.7.30-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/fabric/wooden_hoppers/WoodenHoppersModule.java <==
package net.mehvahdjukaar.every_compat.modules.fabric.wooden_hoppers;

import io.github.haykam821.woodenhoppers.Main;
import io.github.haykam821.woodenhoppers.block.WoodenHopperBlock;
import io.github.haykam821.woodenhoppers.tag.WoodenHoppersBlockTags;
import io.github.haykam821.woodenhoppers.tag.WoodenHoppersItemTags;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_2248;
import net.minecraft.class_3481;
import net.minecraft.class_7706;
import net.minecraft.class_7924;

//SUPPORT: v1.6.0+
public class WoodenHoppersModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, class_2248> hoppers;

    public WoodenHoppersModule(String modId) {
        super(modId, "wh");

        hoppers = SimpleEntrySet.builder(WoodType.class, "hopper",
                        getModBlock("oak_hopper"), () -> WoodTypeRegistry.OAK_TYPE,
                        w -> new WoodenHopperBlock(Utils.copyPropertySafe(w.planks).method_9632(2))
                )
                .addTile(() -> Main.WOODEN_HOPPER_BLOCK_ENTITY_TYPE)
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(WoodenHoppersBlockTags.WOODEN_HOPPERS, class_7924.field_41254)
                .addTag(WoodenHoppersItemTags.WOODEN_HOPPERS, class_7924.field_41197)
                .setTabKey(class_7706.field_40197)
                .defaultRecipe()
                .build();
        this.addEntry(hoppers);

    }
}

==> everycomp-1.20-2.9.10-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/fabric/wooden_hoppers/WoodenHoppersModule.java <==
package net.mehvahdjukaar.every_compat.modules.fabric.wooden_hoppers;

import io.github.haykam821.woodenhoppers.Main;
import io.github.haykam821.woodenhoppers.block.WoodenHopperBlock;
import io.github.haykam821.woodenhoppers.tag.WoodenHoppersBlockTags;
import io.github.haykam821.woodenhoppers.tag.WoodenHoppersItemTags;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_2248;
import net.minecraft.class_3481;
import net.minecraft.class_7706;
import net.minecraft.class_7924;

//SUPPORT: v1.6.0+
public class WoodenHoppersModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, class_2248> hoppers;

    public WoodenHoppersModule(String modId) {
        super(modId, "wh");

        hoppers = SimpleEntrySet.builder(WoodType.class, "hopper",
                        getModBlock("oak_hopper"), () -> VanillaWoodTypes.OAK,
                        w -> new WoodenHopperBlock(Utils.copyPropertySafe(w.planks).method_9632(2))
                )
                .addTile(() -> Main.WOODEN_HOPPER_BLOCK_ENTITY_TYPE)
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(WoodenHoppersBlockTags.WOODEN_HOPPERS, class_7924.field_41254)
                .addTag(WoodenHoppersItemTags.WOODEN_HOPPERS, class_7924.field_41197)
                .setTabKey(class_7706.field_40197)
                .defaultRecipe()
                .build();
        this.addEntry(hoppers);

    }
}
